==> openstory-8.x-2.25.tar.gz: openstory/src/Plugin/rest/resource/GetEntityExistingTranslations.php <==
<?php

namespace Drupal\openstory\Plugin\rest\resource;

use Drupal\rest\Plugin\ResourceBase;
use Drupal\rest\ResourceResponse;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Exception;
use Psr\Log\LoggerInterface;

/**
 * Provides a resource to get a list of entity types.
 *
 * @RestResource(
 *   id = "get_entity_translations",
 *   label = @Translation("Get entity existing translations"),
 *   uri_paths = {
 *     "canonical" = "/get_entity_translations/{entity_type}/{entity_id}"
 *   }
 * )
 */
class GetEntityExistingTranslations extends ResourceBase {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Constructs a Drupal\rest\Plugin\ResourceBase object.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param array $serializer_formats
   *   The available serialization formats.
   * @param \Psr\Log\LoggerInterface $logger
   *   A logger instance.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, array $serializer_formats, LoggerInterface $logger, EntityTypeManagerInterface $entity_type_manager) {
    parent::__construct($configuration, $plugin_id, $plugin_definition, $serializer_formats, $logger);
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
        $configuration,
        $plugin_id,
        $plugin_definition,
        $container->getParameter('serializer.formats'),
        $container->get('logger.factory')->get('custom_rest'),
        $container->get('entity_type.manager'),
    );
  }

  /**
   * Returns information about all entity types on the systems.
   *
   * @throws \Symfony\Component\HttpKernel\Exception\HttpException
   *   Throws exception expected.
   */
  public function get($entityType, $entityId) {

    $entityTypeStorage = $this->entityTypeManager->getStorage($entityType);

    if (!isset($entityTypeStorage)) {
      $result = "EntityType does not exist.";
      $response = new ResourceResponse($result, 400);

    }
    else {

      $entity = $entityTypeStorage->load($entityId);

      if (!isset($entity)) {
        $result = "Entity does not exist.";
        $response = new ResourceResponse($result, 400);
      }
      else {
        $langcodes = \Drupal::languageManager()->getLanguages();

        foreach ($langcodes as $langcode => $langinfo) {
          unset($translation);

          try {
            $translation = $entity->getTranslation($langcode);
            $existingTranslation = TRUE;
          }
          catch (Exception $e) {
            $existingTranslation = FALSE;
          }

          if ($existingTranslation == TRUE) {
            $result[$langcode] = TRUE;
          }
          else {
            $result[$langcode] = FALSE;
          }
        }

        $response = new ResourceResponse($result, 200);
        $response->addCacheableDependency($translation);
      }
    }
    return $response;
  }

}

==> openstory-8.x-2.26.tar.gz: openstory/src/Plugin/rest/resource/GetEntityExistingTranslations.php <==
<?php

namespace Drupal\openstory\Plugin\rest\resource;

use Drupal\rest\Plugin\ResourceBase;
use Drupal\rest\ResourceResponse;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Exception;
use Psr\Log\LoggerInterface;

/**
 * Provides a resource to get a list of entity types.
 *
 * @RestResource(
 *   id = "get_entity_translations",
 *   label = @Translation("Get entity existing translations"),
 *   uri_paths = {
 *     "canonical" = "/get_entity_translations/{entity_type}/{entity_id}"
 *   }
 * )
 */
class GetEntityExistingTranslations extends ResourceBase {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Constructs a Drupal\rest\Plugin\ResourceBase object.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param array $serializer_formats
   *   The available serialization formats.
   * @param \Psr\Log\LoggerInterface $logger
   *   A logger instance.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, array $serializer_formats, LoggerInterface $logger, EntityTypeManagerInterface $entity_type_manager) {
    parent::__construct($configuration, $plugin_id, $plugin_definition, $serializer_formats, $logger);
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
        $configuration,
        $plugin_id,
        $plugin_definition,
        $container->getParameter('serializer.formats'),
        $container->get('logger.factory')->get('custom_rest'),
        $container->get('entity_type.manager')
    );
  }

  /**
   * Returns information about all entity types on the systems.
   *
   * @throws \Symfony\Component\HttpKernel\Exception\HttpException
   *   Throws exception expected.
   */
  public function get($entityType, $entityId) {

    $entityTypeStorage = $this->entityTypeManager->getStorage($entityType);

    if (!isset($entityTypeStorage)) {
      $result = "EntityType does not exist.";
      $response = new ResourceResponse($result, 400);

    }
    else {

      $entity = $entityTypeStorage->load($entityId);

      if (!isset($entity)) {
        $result = "Entity does not exist.";
        $response = new ResourceResponse($result, 400);
      }
      else {
        $langcodes = \Drupal::languageManager()->getLanguages();

        foreach ($langcodes as $langcode => $langinfo) {
          unset($translation);

          try {
            $translation = $entity->getTranslation($langcode);
            $existingTranslation = TRUE;
          }
          catch (Exception $e) {
            $existingTranslation = FALSE;
          }

          if ($existingTranslation == TRUE) {
            $result[$langcode] = TRUE;
          }
          else {
            $result[$langcode] = FALSE;
          }
        }

        $response = new ResourceResponse($result, 200);
        $response->addCacheableDependency($translation);
      }
    }
    return $response;
  }

}
